@@ -34,7 +34,7 @@
 
 using namespace Fm;
 
-FolderModel::FolderModel() : 
+FolderModel::FolderModel() :
   folder_(NULL) {
 /*
     ColumnIcon,
@@ -44,7 +44,7 @@ FolderModel::FolderModel() :
     NumOfColumns
 */
   thumbnailRefCounts.reserve(4);
-  
+
   // reload all icons when the icon theme is changed
   connect(IconTheme::instance(), &IconTheme::changed, this, &FolderModel::updateIcons);
 }
@@ -54,7 +54,7 @@ FolderModel::~FolderModel() {
 
   if(folder_)
     setFolder(NULL);
-  
+
   // if the thumbnail requests list is not empty, cancel them
   if(!thumbnailResults.empty()) {
     Q_FOREACH(FmThumbnailLoader* res, thumbnailResults) {
@@ -95,7 +95,8 @@ void FolderModel::onStartLoading(FmFolder* folder, gpointer user_data) {
 }
 
 void FolderModel::onFinishLoading(FmFolder* folder, gpointer user_data) {
-  FolderModel* model = static_cast<FolderModel*>(user_data);
+  Q_UNUSED(folder)
+  Q_UNUSED(user_data)
 }
 
 void FolderModel::onFilesAdded(FmFolder* folder, GSList* files, gpointer user_data) {
@@ -119,7 +120,6 @@ void FolderModel::onFilesAdded(FmFolder* folder, GSList* files, gpointer user_da
 //static
 void FolderModel::onFilesChanged(FmFolder* folder, GSList* files, gpointer user_data) {
   FolderModel* model = static_cast<FolderModel*>(user_data);
-  int n_files = g_slist_length(files);
   for(GSList* l = files; l; l = l->next) {
     FmFileInfo* info = FM_FILE_INFO(l->data);
     int row;
@@ -218,12 +218,10 @@ QVariant FolderModel::data(const QModelIndex & index, int role = Qt::DisplayRole
         case ColumnFileSize: {
           const char* name = fm_file_info_get_disp_size(info);
           return QString::fromUtf8(name);
-          break;
         }
         case ColumnFileOwner: {
           const char* name = fm_file_info_get_disp_owner(info);
           return QString::fromUtf8(name);
-          break;
         }
       }
     }
@@ -233,6 +231,7 @@ QVariant FolderModel::data(const QModelIndex & index, int role = Qt::DisplayRole
         return QVariant(item->icon);
         // return QVariant(pix);
       }
+      break;
     }
     case FileInfoRole:
       return qVariantFromValue((void*)info);
@@ -292,7 +291,7 @@ Qt::ItemFlags FolderModel::flags(const QModelIndex& index) const {
   return flags;
 }
 
-// FIXME: this is very inefficient and should be replaced with a 
+// FIXME: this is very inefficient and should be replaced with a
 // more reasonable implementation later.
 QList<FolderModelItem>::iterator FolderModel::findItemByPath(FmPath* path, int* row) {
   QList<FolderModelItem>::iterator it = items.begin();
@@ -310,7 +309,7 @@ QList<FolderModelItem>::iterator FolderModel::findItemByPath(FmPath* path, int*
   return items.end();
 }
 
-// FIXME: this is very inefficient and should be replaced with a 
+// FIXME: this is very inefficient and should be replaced with a
 // more reasonable implementation later.
 QList<FolderModelItem>::iterator FolderModel::findItemByName(const char* name, int* row) {
   QList<FolderModelItem>::iterator it = items.begin();
@@ -358,7 +357,7 @@ QMimeData* FolderModel::mimeData(const QModelIndexList& indexes) const {
   // build a uri list
   QByteArray urilist;
   urilist.reserve(4096);
-  
+
   QModelIndexList::const_iterator it;
   for(it = indexes.constBegin(); it != indexes.end(); ++it) {
     const QModelIndex index = *it;
@@ -372,7 +371,7 @@ QMimeData* FolderModel::mimeData(const QModelIndexList& indexes) const {
     }
   }
   data->setData("text/uri-list", urilist);
-  
+
   return data;
 }
 
