@@ -66,7 +66,7 @@ void FolderViewListView::mousePressEvent(QMouseEvent* event) {
 
 QModelIndex FolderViewListView::indexAt(const QPoint& point) const {
   QModelIndex index = QListView::indexAt(point);
-  // NOTE: QListView has a severe design flaw here. It does hit-testing based on the 
+  // NOTE: QListView has a severe design flaw here. It does hit-testing based on the
   // total bound rect of the item. The width of an item is determined by max(icon_width, text_width).
   // So if the text label is much wider than the icon, when you click outside the icon but
   // the point is still within the outer bound rect, the item is still selected.
@@ -181,7 +181,7 @@ FolderViewTreeView::FolderViewTreeView(QWidget* parent):
   doingLayout_(false),
   activationAllowed_(true) {
 
-  header()->setStretchLastSection(false);
+  header()->setStretchLastSection(true);
   setIndentation(0);
 
   connect(this, &QTreeView::activated, this, &FolderViewTreeView::activation);
@@ -195,6 +195,11 @@ FolderViewTreeView::~FolderViewTreeView() {
 void FolderViewTreeView::setModel(QAbstractItemModel* model) {
   QTreeView::setModel(model);
   layoutColumns();
+  if(ProxyFolderModel* proxyModel = qobject_cast<ProxyFolderModel*>(model)) {
+    connect(proxyModel, &ProxyFolderModel::sortFilterChanged, this, &FolderViewTreeView::onSortFilterChanged,
+            Qt::UniqueConnection);
+    onSortFilterChanged();
+  }
 }
 
 void FolderViewTreeView::mousePressEvent(QMouseEvent* event) {
@@ -237,48 +242,48 @@ void FolderViewTreeView::layoutColumns() {
 
   // get the width that every column want
   int numCols = headerView->count();
-  int* widths = new int[numCols]; // array to store the widths every column needs
-  int column;
-  for(column = 0; column < numCols; ++column) {
-    int columnId = headerView->logicalIndex(column);
-    // get the size that the column needs
-    widths[column] = sizeHintForColumn(columnId);
-  }
+  if(numCols > 0) {
+    int* widths = new int[numCols]; // array to store the widths every column needs
+    int column;
+    for(column = 0; column < numCols; ++column) {
+      int columnId = headerView->logicalIndex(column);
+      // get the size that the column needs
+      widths[column] = sizeHintForColumn(columnId);
+      // compute the total width needed
+      desiredWidth += widths[column];
+    }
 
-  // the best case is every column can get its full width
-  for(column = 0; column < numCols; ++column) {
-    desiredWidth += widths[column];
-  }
-
-  // if the total witdh we want exceeds the available space
-  if(desiredWidth > availWidth) {
-    // we don't have that much space for every column
     int filenameColumn = headerView->visualIndex(FolderModel::ColumnFileName);
-    // shrink the filename column first
-    desiredWidth -= widths[filenameColumn]; // total width of all other columns
+    // if the total witdh we want exceeds the available space
+    if(desiredWidth > availWidth) {
+      // Compute the width available for the filename column
+      int filenameAvailWidth = availWidth - desiredWidth + widths[filenameColumn];
 
-    // see if setting the width of the filename column to 200 solve the problem
-    if(desiredWidth + 200 > availWidth) {
-      // even when we reduce the width of the filename column to 200,
-      // the available space is not enough. So we give up trying.
-      widths[filenameColumn] = 200;
-      desiredWidth += 200;
+      // Compute the minimum acceptable width for the filename column
+      int filenameMinWidth = qMin(200, sizeHintForColumn(filenameColumn));
+
+      if (filenameAvailWidth > filenameMinWidth) {
+        // Shrink the filename column to the available width
+        widths[filenameColumn] = filenameAvailWidth;
+      }
+      else {
+        // Set the filename column to its minimum width
+        widths[filenameColumn] = filenameMinWidth;
+      }
     }
-    else { // we still have more space, so the width of filename column can be increased
-      // expand the filename column to fill all available space.
-      widths[filenameColumn] = availWidth - desiredWidth;
-      desiredWidth = availWidth;
+    else {
+      // Fill the extra available space with the filename column
+      widths[filenameColumn] += availWidth - desiredWidth;
     }
-  }
 
-  // really do the resizing for every column
-  for(int column = 0; column < numCols; ++column) {
-    headerView->resizeSection(column, widths[column]);
+    // really do the resizing for every column
+    for(int column = 0; column < numCols; ++column) {
+      headerView->resizeSection(column, widths[column]);
+    }
+    delete []widths;
   }
-
-  delete []widths;
   doingLayout_ = false;
-  
+
   if(layoutTimer_) {
     delete layoutTimer_;
     layoutTimer_ = NULL;
@@ -287,7 +292,13 @@ void FolderViewTreeView::layoutColumns() {
 
 void FolderViewTreeView::resizeEvent(QResizeEvent* event) {
   QAbstractItemView::resizeEvent(event);
-  if(!doingLayout_) // prevent endless recursion.
+  // prevent endless recursion.
+  // When manually resizing columns, at the point where a horizontal scroll
+  // bar has to be inserted or removed, the vertical size changes, a resize
+  // event  occurs and the column headers are flickering badly if the column
+  // layout is modified at this point. Therefore only layout the columns if
+  // the horizontal size changes.
+  if(!doingLayout_ && event->size().width() != event->oldSize().width())
     layoutColumns(); // layoutColumns() also triggers resizeEvent
 }
 
@@ -307,6 +318,17 @@ void FolderViewTreeView::dataChanged(const QModelIndex& topLeft, const QModelInd
   // queueLayoutColumns();
 }
 
+void FolderViewTreeView::reset() {
+  // Sometimes when the content of the model is radically changed, Qt does reset()
+  // on the model rather than doing large amount of insertion and deletion.
+  // This is for performance reason so in this case rowsInserted() and rowsAboutToBeRemoved()
+  // might not be called. Hence we also have to re-layout the columns when the model is reset.
+  // This fixes bug #190
+  // https://github.com/lxde/pcmanfm-qt/issues/190
+  QTreeView::reset();
+  queueLayoutColumns();
+}
+
 void FolderViewTreeView::queueLayoutColumns() {
   // qDebug("queueLayoutColumns");
   if(!layoutTimer_) {
@@ -346,6 +368,16 @@ void FolderViewTreeView::activation(const QModelIndex &index) {
   }
 }
 
+void FolderViewTreeView::onSortFilterChanged() {
+  if(QSortFilterProxyModel* proxyModel = qobject_cast<QSortFilterProxyModel*>(model())) {
+    header()->setSortIndicatorShown(true);
+    header()->setSortIndicator(proxyModel->sortColumn(), proxyModel->sortOrder());
+    if (!isSortingEnabled()) {
+      setSortingEnabled(true);
+    }
+  }
+}
+
 
 //-----------------------------------------------------------------------------
 
@@ -375,7 +407,6 @@ FolderView::FolderView(ViewMode _mode, QWidget* parent):
 }
 
 FolderView::~FolderView() {
-  // qDebug("delete FolderView");
 }
 
 void FolderView::onItemActivated(QModelIndex index) {
@@ -423,7 +454,7 @@ void FolderView::setViewMode(ViewMode _mode) {
     return;
   // FIXME: retain old selection
 
-  // since only detailed list mode uses QTreeView, and others 
+  // since only detailed list mode uses QTreeView, and others
   // all use QListView, it's wise to preserve QListView when possible.
   bool recreateView = false;
   if(view && (mode == DetailedListMode || _mode == DetailedListMode)) {
@@ -616,8 +647,13 @@ void FolderView::contextMenuEvent(QContextMenuEvent* event) {
 
 void FolderView::childMousePressEvent(QMouseEvent* event) {
   // called from mousePressEvent() of child view
-  if(event->button() == Qt::MiddleButton) {
+  Qt::MouseButton button = event->button();
+  if(button == Qt::MiddleButton) {
     emitClickedAt(MiddleClick, event->pos());
+  } else if (button == Qt::BackButton) {
+    Q_EMIT clickedBack();
+  } else if (button == Qt::ForwardButton) {
+    Q_EMIT clickedForward();
   }
 }
 
@@ -683,7 +719,7 @@ FmFileInfoList* FolderView::selectedFiles() const {
     if(!selIndexes.isEmpty()) {
       FmFileInfoList* files = fm_file_info_list_new();
       QModelIndexList::const_iterator it;
-      for(it = selIndexes.constBegin(); it != selIndexes.constEnd(); it++) {
+      for(it = selIndexes.constBegin(); it != selIndexes.constEnd(); ++it) {
         FmFileInfo* file = model_->fileInfoFromIndex(*it);
         fm_file_info_list_push_tail(files, file);
       }
@@ -892,7 +928,15 @@ void FolderView::onFileClicked(int type, FmFileInfo* fileInfo) {
     }
   }
   else if(type == ContextMenuClick) {
-    FmPath* folderPath = path();
+    FmPath* folderPath = NULL;
+    FmFileInfoList* files = selectedFiles();
+    if (files) {
+      FmFileInfo* first = fm_file_info_list_peek_head(files);
+      if (fm_file_info_list_get_length(files) == 1 && fm_file_info_is_dir(first))
+        folderPath = fm_file_info_get_path(first);
+    }
+    if (!folderPath)
+      folderPath = path();
     QMenu* menu = NULL;
     if(fileInfo) {
       // show context menu
@@ -905,15 +949,13 @@ void FolderView::onFileClicked(int type, FmFileInfo* fileInfo) {
       }
     }
     else {
-      FmFolder* _folder = folder();
-      FmFileInfo* info = fm_folder_get_info(_folder);
       Fm::FolderMenu* folderMenu = new Fm::FolderMenu(this);
       prepareFolderMenu(folderMenu);
       menu = folderMenu;
     }
     if (menu) {
-      menu->popup(QCursor::pos());
-      connect(menu, &QMenu::aboutToHide, menu, &QMenu::deleteLater);
+      menu->exec(QCursor::pos());
+      delete menu;
     }
   }
 }
