@@ -158,133 +158,133 @@
         <translation>Свойства файла</translation>
     </message>
     <message>
-        <location filename="../file-props.ui" line="32"/>
+        <location filename="../file-props.ui" line="41"/>
         <source>General</source>
         <translation>Общие</translation>
     </message>
     <message>
-        <location filename="../file-props.ui" line="71"/>
+        <location filename="../file-props.ui" line="80"/>
         <source>Location:</source>
         <translation>Расположение:</translation>
     </message>
     <message>
-        <location filename="../file-props.ui" line="94"/>
+        <location filename="../file-props.ui" line="106"/>
         <source>File type:</source>
         <translation>Тип файла:</translation>
     </message>
     <message>
-        <location filename="../file-props.ui" line="114"/>
+        <location filename="../file-props.ui" line="129"/>
         <source>Mime type:</source>
         <translation>Тип Mime:</translation>
     </message>
     <message>
-        <location filename="../file-props.ui" line="134"/>
+        <location filename="../file-props.ui" line="152"/>
         <source>File size:</source>
         <translation>Размер файла:</translation>
     </message>
     <message>
-        <location filename="../file-props.ui" line="154"/>
+        <location filename="../file-props.ui" line="175"/>
         <source>On-disk size:</source>
         <translation>Размер на диске:</translation>
     </message>
     <message>
-        <location filename="../file-props.ui" line="174"/>
+        <location filename="../file-props.ui" line="198"/>
         <source>Last modified:</source>
         <translation>Последнее изменение:</translation>
     </message>
     <message>
-        <location filename="../file-props.ui" line="194"/>
+        <location filename="../file-props.ui" line="221"/>
         <source>Link target:</source>
         <translation>Цель ссылки:</translation>
     </message>
     <message>
-        <location filename="../file-props.ui" line="217"/>
+        <location filename="../file-props.ui" line="247"/>
         <source>Open With:</source>
         <translation>Открыть с помощью:</translation>
     </message>
     <message>
-        <location filename="../file-props.ui" line="234"/>
+        <location filename="../file-props.ui" line="267"/>
         <source>Last accessed:</source>
         <translation>Последний доступ:</translation>
     </message>
     <message>
-        <location filename="../file-props.ui" line="249"/>
+        <location filename="../file-props.ui" line="285"/>
         <source>Permissions</source>
         <translation>Разрешения</translation>
     </message>
     <message>
-        <location filename="../file-props.ui" line="264"/>
+        <location filename="../file-props.ui" line="300"/>
         <source>Ownership</source>
         <translation>Владение</translation>
     </message>
     <message>
-        <location filename="../file-props.ui" line="288"/>
-        <location filename="../file-props.ui" line="353"/>
-        <location filename="../file-props.ui" line="467"/>
+        <location filename="../file-props.ui" line="324"/>
+        <location filename="../file-props.ui" line="389"/>
+        <location filename="../file-props.ui" line="503"/>
         <source>Group:</source>
         <translation>Группа:</translation>
     </message>
     <message>
-        <location filename="../file-props.ui" line="301"/>
-        <location filename="../file-props.ui" line="336"/>
-        <location filename="../file-props.ui" line="415"/>
+        <location filename="../file-props.ui" line="337"/>
+        <location filename="../file-props.ui" line="372"/>
+        <location filename="../file-props.ui" line="451"/>
         <source>Owner:</source>
         <translation>Владелец:</translation>
     </message>
     <message>
-        <location filename="../file-props.ui" line="317"/>
+        <location filename="../file-props.ui" line="353"/>
         <source>Access Control</source>
         <translation>Контроль доступа</translation>
     </message>
     <message>
-        <location filename="../file-props.ui" line="370"/>
-        <location filename="../file-props.ui" line="519"/>
+        <location filename="../file-props.ui" line="406"/>
+        <location filename="../file-props.ui" line="555"/>
         <source>Other:</source>
         <translation>Остальные:</translation>
     </message>
     <message>
-        <location filename="../file-props.ui" line="387"/>
+        <location filename="../file-props.ui" line="423"/>
         <source>Make the file executable</source>
         <translation>Сделать файл исполняемым</translation>
     </message>
     <message>
-        <location filename="../file-props.ui" line="428"/>
-        <location filename="../file-props.ui" line="480"/>
-        <location filename="../file-props.ui" line="532"/>
+        <location filename="../file-props.ui" line="464"/>
+        <location filename="../file-props.ui" line="516"/>
+        <location filename="../file-props.ui" line="568"/>
         <source>Read</source>
         <translation>Чтение</translation>
     </message>
     <message>
-        <location filename="../file-props.ui" line="441"/>
-        <location filename="../file-props.ui" line="493"/>
-        <location filename="../file-props.ui" line="545"/>
+        <location filename="../file-props.ui" line="477"/>
+        <location filename="../file-props.ui" line="529"/>
+        <location filename="../file-props.ui" line="581"/>
         <source>Write</source>
         <translation>Запись</translation>
     </message>
     <message>
-        <location filename="../file-props.ui" line="454"/>
-        <location filename="../file-props.ui" line="506"/>
-        <location filename="../file-props.ui" line="558"/>
+        <location filename="../file-props.ui" line="490"/>
+        <location filename="../file-props.ui" line="542"/>
+        <location filename="../file-props.ui" line="594"/>
         <source>Execute</source>
         <translation>Выполнение</translation>
     </message>
     <message>
-        <location filename="../file-props.ui" line="567"/>
+        <location filename="../file-props.ui" line="603"/>
         <source>Sticky</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../file-props.ui" line="574"/>
+        <location filename="../file-props.ui" line="610"/>
         <source>SetUID</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../file-props.ui" line="581"/>
+        <location filename="../file-props.ui" line="617"/>
         <source>SetGID</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../file-props.ui" line="617"/>
+        <location filename="../file-props.ui" line="653"/>
         <source>Advanced Mode</source>
         <translation>Расширенный режим</translation>
     </message>
@@ -305,6 +305,19 @@
         <translation>Выберите приложение, чтобы открыть &quot;%1&quot; файлов</translation>
     </message>
 </context>
+<context>
+    <name>Fm::CreateNewMenu</name>
+    <message>
+        <location filename="../createnewmenu.cpp" line="29"/>
+        <source>Folder</source>
+        <translation>Папку</translation>
+    </message>
+    <message>
+        <location filename="../createnewmenu.cpp" line="33"/>
+        <source>Blank File</source>
+        <translation>Пустой файл</translation>
+    </message>
+</context>
 <context>
     <name>Fm::DirTreeModel</name>
     <message>
@@ -318,6 +331,24 @@
         <translation>&lt;Нет подпапок&gt;</translation>
     </message>
 </context>
+<context>
+    <name>Fm::DirTreeView</name>
+    <message>
+        <location filename="../dirtreeview.cpp" line="208"/>
+        <source>Open in New T&amp;ab</source>
+        <translation>Открыть в новой вкл&amp;адке</translation>
+    </message>
+    <message>
+        <location filename="../dirtreeview.cpp" line="212"/>
+        <source>Open in New Win&amp;dow</source>
+        <translation>Открыть в новом о&amp;кне</translation>
+    </message>
+    <message>
+        <location filename="../dirtreeview.cpp" line="217"/>
+        <source>Open in Termina&amp;l</source>
+        <translation>Открыть в термина&amp;ле</translation>
+    </message>
+</context>
 <context>
     <name>Fm::DndActionMenu</name>
     <message>
@@ -344,7 +375,7 @@
 <context>
     <name>Fm::EditBookmarksDialog</name>
     <message>
-        <location filename="../editbookmarksdialog.cpp" line="95"/>
+        <location filename="../editbookmarksdialog.cpp" line="96"/>
         <source>New bookmark</source>
         <translation>Новая закладка</translation>
     </message>
@@ -355,7 +386,7 @@
         <location filename="../execfiledialog.cpp" line="40"/>
         <source>This text file &apos;%1&apos; seems to be an executable script.
 What do you want to do with it?</source>
-        <translation type="unfinished">Этот текстовый файл &apos;%1&apos; похож на исполняемый скрипт.
+        <translation>Этот текстовый файл &apos;%1&apos; похож на исполняемый скрипт.
 Что вы хотите с ним сделать?</translation>
     </message>
     <message>
@@ -367,78 +398,83 @@ What do you want to do with it?</source>
 <context>
     <name>Fm::FileMenu</name>
     <message>
-        <location filename="../filemenu.cpp" line="78"/>
+        <location filename="../filemenu.cpp" line="94"/>
         <source>Open</source>
         <translation>Открыть</translation>
     </message>
     <message>
-        <location filename="../filemenu.cpp" line="82"/>
+        <location filename="../filemenu.cpp" line="98"/>
         <source>Open With...</source>
         <translation>Открыть с помощью...</translation>
     </message>
     <message>
-        <location filename="../filemenu.cpp" line="110"/>
+        <location filename="../filemenu.cpp" line="126"/>
         <source>Other Applications</source>
         <translation>Другие приложения</translation>
     </message>
     <message>
-        <location filename="../filemenu.cpp" line="128"/>
-        <source>&amp;Restore</source>
-        <translation type="unfinished"></translation>
+        <location filename="../filemenu.cpp" line="132"/>
+        <source>Create &amp;New</source>
+        <translation>&amp;Создать</translation>
     </message>
     <message>
-        <location filename="../filemenu.cpp" line="134"/>
+        <location filename="../filemenu.cpp" line="151"/>
+        <source>&amp;Restore</source>
+        <translation>&amp;Восстановить</translation>
+    </message>
+    <message>
+        <location filename="../filemenu.cpp" line="157"/>
         <source>Cut</source>
         <translation>Вырезать</translation>
     </message>
     <message>
-        <location filename="../filemenu.cpp" line="138"/>
+        <location filename="../filemenu.cpp" line="161"/>
         <source>Copy</source>
         <translation>Копировать</translation>
     </message>
     <message>
-        <location filename="../filemenu.cpp" line="142"/>
+        <location filename="../filemenu.cpp" line="165"/>
         <source>Paste</source>
         <translation>Вставить</translation>
     </message>
     <message>
-        <location filename="../filemenu.cpp" line="146"/>
-        <location filename="../filemenu.cpp" line="339"/>
+        <location filename="../filemenu.cpp" line="169"/>
+        <location filename="../filemenu.cpp" line="363"/>
         <source>&amp;Move to Trash</source>
         <translation>&amp;Переместить в корзину</translation>
     </message>
     <message>
-        <location filename="../filemenu.cpp" line="150"/>
+        <location filename="../filemenu.cpp" line="173"/>
         <source>Rename</source>
         <translation>Переименовать</translation>
     </message>
     <message>
-        <location filename="../filemenu.cpp" line="177"/>
+        <location filename="../filemenu.cpp" line="200"/>
         <source>Extract to...</source>
         <translation>Распаковать в ...</translation>
     </message>
     <message>
-        <location filename="../filemenu.cpp" line="182"/>
+        <location filename="../filemenu.cpp" line="205"/>
         <source>Extract Here</source>
         <translation>Распаковать здесь</translation>
     </message>
     <message>
-        <location filename="../filemenu.cpp" line="188"/>
+        <location filename="../filemenu.cpp" line="211"/>
         <source>Compress</source>
         <translation>Сжать</translation>
     </message>
     <message>
-        <location filename="../filemenu.cpp" line="198"/>
+        <location filename="../filemenu.cpp" line="221"/>
         <source>Properties</source>
         <translation>Свойства</translation>
     </message>
     <message>
-        <location filename="../filemenu.cpp" line="289"/>
+        <location filename="../filemenu.cpp" line="312"/>
         <source>Output</source>
         <translation>Вывод</translation>
     </message>
     <message>
-        <location filename="../filemenu.cpp" line="339"/>
+        <location filename="../filemenu.cpp" line="363"/>
         <source>&amp;Delete</source>
         <translation>&amp;Удалить</translation>
     </message>
@@ -446,30 +482,30 @@ What do you want to do with it?</source>
 <context>
     <name>Fm::FileOperation</name>
     <message>
-        <location filename="../fileoperation.cpp" line="188"/>
+        <location filename="../fileoperation.cpp" line="220"/>
         <source>Error</source>
-        <translation type="unfinished">Ошибка</translation>
+        <translation>Ошибка</translation>
     </message>
     <message>
-        <location filename="../fileoperation.cpp" line="189"/>
+        <location filename="../fileoperation.cpp" line="221"/>
         <source>Some files cannot be moved to trash can because the underlying file systems don&apos;t support this operation.
 Do you want to delete them instead?</source>
         <translation>Некоторые файлы не могут быть помещены в корзину, поскольку файловая система не поддерживает эту операцию.
 Вы всё равно хотите их удалить?</translation>
     </message>
     <message>
-        <location filename="../fileoperation.cpp" line="230"/>
-        <location filename="../fileoperation.cpp" line="246"/>
+        <location filename="../fileoperation.cpp" line="262"/>
+        <location filename="../fileoperation.cpp" line="278"/>
         <source>Confirm</source>
         <translation>Подтвердить</translation>
     </message>
     <message>
-        <location filename="../fileoperation.cpp" line="231"/>
+        <location filename="../fileoperation.cpp" line="263"/>
         <source>Do you want to delete the selected files?</source>
         <translation>Вы действительно хотите удалить выбранные файлы?</translation>
     </message>
     <message>
-        <location filename="../fileoperation.cpp" line="247"/>
+        <location filename="../fileoperation.cpp" line="279"/>
         <source>Do you want to move the selected files to trash can?</source>
         <translation>Переместить выбранные файлы в корзину?</translation>
     </message>
@@ -600,10 +636,28 @@ Do you want to delete them instead?</source>
         <translation>Применить изменения рекурсивно ко всем файлам и подпапкам?</translation>
     </message>
 </context>
+<context>
+    <name>Fm::FileSearchDialog</name>
+    <message>
+        <location filename="../filesearchdialog.cpp" line="120"/>
+        <source>Error</source>
+        <translation>Ошибка</translation>
+    </message>
+    <message>
+        <location filename="../filesearchdialog.cpp" line="120"/>
+        <source>You should add at least add one directory to search.</source>
+        <translation>Вы должны добавить не менее одного места для поиска.</translation>
+    </message>
+    <message>
+        <location filename="../filesearchdialog.cpp" line="127"/>
+        <source>Select a folder</source>
+        <translation>Выберите папку</translation>
+    </message>
+</context>
 <context>
     <name>Fm::FolderMenu</name>
     <message>
-        <location filename="../foldermenu.cpp" line="36"/>
+        <location filename="../foldermenu.cpp" line="37"/>
         <source>Create &amp;New</source>
         <translation>&amp;Создать</translation>
     </message>
@@ -638,57 +692,47 @@ Do you want to delete them instead?</source>
         <translation>&amp;Свойства папки</translation>
     </message>
     <message>
-        <location filename="../foldermenu.cpp" line="85"/>
-        <source>Folder</source>
-        <translation>Папку</translation>
-    </message>
-    <message>
-        <location filename="../foldermenu.cpp" line="89"/>
-        <source>Blank File</source>
-        <translation>Пустой файл</translation>
-    </message>
-    <message>
-        <location filename="../foldermenu.cpp" line="133"/>
+        <location filename="../foldermenu.cpp" line="99"/>
         <source>By File Name</source>
         <translation>По имени</translation>
     </message>
     <message>
-        <location filename="../foldermenu.cpp" line="134"/>
+        <location filename="../foldermenu.cpp" line="100"/>
         <source>By Modification Time</source>
         <translation>По времени изменения</translation>
     </message>
     <message>
-        <location filename="../foldermenu.cpp" line="135"/>
+        <location filename="../foldermenu.cpp" line="101"/>
         <source>By File Size</source>
         <translation>По размеру</translation>
     </message>
     <message>
-        <location filename="../foldermenu.cpp" line="136"/>
+        <location filename="../foldermenu.cpp" line="102"/>
         <source>By File Type</source>
         <translation>По типу</translation>
     </message>
     <message>
-        <location filename="../foldermenu.cpp" line="137"/>
+        <location filename="../foldermenu.cpp" line="103"/>
         <source>By File Owner</source>
         <translation>По владельцу</translation>
     </message>
     <message>
-        <location filename="../foldermenu.cpp" line="149"/>
+        <location filename="../foldermenu.cpp" line="115"/>
         <source>Ascending</source>
         <translation>Возрастающая</translation>
     </message>
     <message>
-        <location filename="../foldermenu.cpp" line="154"/>
+        <location filename="../foldermenu.cpp" line="120"/>
         <source>Descending</source>
         <translation>Убывающая</translation>
     </message>
     <message>
-        <location filename="../foldermenu.cpp" line="169"/>
+        <location filename="../foldermenu.cpp" line="135"/>
         <source>Folder First</source>
         <translation>Сначала папки</translation>
     </message>
     <message>
-        <location filename="../foldermenu.cpp" line="178"/>
+        <location filename="../foldermenu.cpp" line="144"/>
         <source>Case Sensitive</source>
         <translation>Регистрочувствительность</translation>
     </message>
@@ -696,27 +740,27 @@ Do you want to delete them instead?</source>
 <context>
     <name>Fm::FolderModel</name>
     <message>
-        <location filename="../foldermodel.cpp" line="249"/>
+        <location filename="../foldermodel.cpp" line="248"/>
         <source>Name</source>
         <translation>Имя</translation>
     </message>
     <message>
-        <location filename="../foldermodel.cpp" line="252"/>
+        <location filename="../foldermodel.cpp" line="251"/>
         <source>Type</source>
         <translation>Тип</translation>
     </message>
     <message>
-        <location filename="../foldermodel.cpp" line="255"/>
+        <location filename="../foldermodel.cpp" line="254"/>
         <source>Size</source>
         <translation>Размер</translation>
     </message>
     <message>
-        <location filename="../foldermodel.cpp" line="258"/>
+        <location filename="../foldermodel.cpp" line="257"/>
         <source>Modified</source>
         <translation>Изменён</translation>
     </message>
     <message>
-        <location filename="../foldermodel.cpp" line="261"/>
+        <location filename="../foldermodel.cpp" line="260"/>
         <source>Owner</source>
         <translation>Владелец</translation>
     </message>
@@ -745,12 +789,12 @@ Do you want to delete them instead?</source>
 <context>
     <name>Fm::PlacesModel</name>
     <message>
-        <location filename="../placesmodel.cpp" line="41"/>
+        <location filename="../placesmodel.cpp" line="40"/>
         <source>Places</source>
         <translation>Места</translation>
     </message>
     <message>
-        <location filename="../placesmodel.cpp" line="49"/>
+        <location filename="../placesmodel.cpp" line="48"/>
         <source>Desktop</source>
         <translation>Рабочий стол</translation>
     </message>
@@ -760,27 +804,27 @@ Do you want to delete them instead?</source>
         <translation>Компьютер</translation>
     </message>
     <message>
-        <location filename="../placesmodel.cpp" line="69"/>
+        <location filename="../placesmodel.cpp" line="70"/>
         <source>Applications</source>
         <translation>Программы</translation>
     </message>
     <message>
-        <location filename="../placesmodel.cpp" line="80"/>
+        <location filename="../placesmodel.cpp" line="82"/>
         <source>Network</source>
         <translation>Сеть</translation>
     </message>
     <message>
-        <location filename="../placesmodel.cpp" line="88"/>
+        <location filename="../placesmodel.cpp" line="90"/>
         <source>Devices</source>
         <translation>Устройства</translation>
     </message>
     <message>
-        <location filename="../placesmodel.cpp" line="130"/>
+        <location filename="../placesmodel.cpp" line="132"/>
         <source>Bookmarks</source>
         <translation>Закладки</translation>
     </message>
     <message>
-        <location filename="../placesmodel.cpp" line="205"/>
+        <location filename="../placesmodel.cpp" line="207"/>
         <source>Trash</source>
         <translation>Корзина</translation>
     </message>
@@ -788,33 +832,53 @@ Do you want to delete them instead?</source>
 <context>
     <name>Fm::PlacesView</name>
     <message>
-        <location filename="../placesview.cpp" line="281"/>
+        <location filename="../placesview.cpp" line="358"/>
         <source>Empty Trash</source>
         <translation>Очистить корзину</translation>
     </message>
     <message>
-        <location filename="../placesview.cpp" line="290"/>
-        <source>Rename</source>
-        <translation>Переименовать</translation>
+        <location filename="../placesview.cpp" line="346"/>
+        <source>Open in New Tab</source>
+        <translation>Открыть в новой вкладке</translation>
     </message>
     <message>
-        <location filename="../placesview.cpp" line="293"/>
-        <source>Delete</source>
-        <translation>Удалить</translation>
+        <location filename="../placesview.cpp" line="349"/>
+        <source>Open in New Window</source>
+        <translation>Открыть в новом окне</translation>
     </message>
     <message>
-        <location filename="../placesview.cpp" line="303"/>
-        <location filename="../placesview.cpp" line="321"/>
+        <location filename="../placesview.cpp" line="367"/>
+        <source>Move Bookmark Up</source>
+        <translation>Сдвинуть закладку вверх</translation>
+    </message>
+    <message>
+        <location filename="../placesview.cpp" line="372"/>
+        <source>Move Bookmark Down</source>
+        <translation>Сдвинуть закладку вниз</translation>
+    </message>
+    <message>
+        <location filename="../placesview.cpp" line="376"/>
+        <source>Rename Bookmark</source>
+        <translation>Переименовать закладку</translation>
+    </message>
+    <message>
+        <location filename="../placesview.cpp" line="379"/>
+        <source>Remove Bookmark</source>
+        <translation>Удалить закладку</translation>
+    </message>
+    <message>
+        <location filename="../placesview.cpp" line="388"/>
+        <location filename="../placesview.cpp" line="405"/>
         <source>Unmount</source>
         <translation>Отключить</translation>
     </message>
     <message>
-        <location filename="../placesview.cpp" line="307"/>
+        <location filename="../placesview.cpp" line="392"/>
         <source>Mount</source>
         <translation>Подключить</translation>
     </message>
     <message>
-        <location filename="../placesview.cpp" line="313"/>
+        <location filename="../placesview.cpp" line="398"/>
         <source>Eject</source>
         <translation>Извлечь</translation>
     </message>
@@ -859,24 +923,24 @@ Modified: %3</source>
 <context>
     <name>Fm::SidePane</name>
     <message>
-        <location filename="../sidepane.cpp" line="46"/>
-        <location filename="../sidepane.cpp" line="125"/>
+        <location filename="../sidepane.cpp" line="47"/>
+        <location filename="../sidepane.cpp" line="127"/>
         <source>Places</source>
         <translation>Места</translation>
     </message>
     <message>
-        <location filename="../sidepane.cpp" line="47"/>
-        <location filename="../sidepane.cpp" line="127"/>
+        <location filename="../sidepane.cpp" line="48"/>
+        <location filename="../sidepane.cpp" line="129"/>
         <source>Directory Tree</source>
         <translation>Дерево папок</translation>
     </message>
     <message>
-        <location filename="../sidepane.cpp" line="135"/>
+        <location filename="../sidepane.cpp" line="137"/>
         <source>Shows list of common places, devices, and bookmarks in sidebar</source>
         <translation>Показывает список обычных мест, устройств и закладок в боковой панели</translation>
     </message>
     <message>
-        <location filename="../sidepane.cpp" line="137"/>
+        <location filename="../sidepane.cpp" line="139"/>
         <source>Shows tree of directories in sidebar</source>
         <translation>Показывает дерево папок в боковой панели</translation>
     </message>
@@ -933,9 +997,9 @@ Modified: %3</source>
     <name>QObject</name>
     <message>
         <location filename="../utilities.cpp" line="152"/>
-        <location filename="../utilities.cpp" line="226"/>
+        <location filename="../utilities.cpp" line="228"/>
         <location filename="../mountoperation.cpp" line="185"/>
-        <location filename="../filelauncher.cpp" line="109"/>
+        <location filename="../filelauncher.cpp" line="117"/>
         <source>Error</source>
         <translation>Ошибка</translation>
     </message>
@@ -950,32 +1014,37 @@ Modified: %3</source>
         <translation>Введите новое имя:</translation>
     </message>
     <message>
-        <location filename="../utilities.cpp" line="167"/>
+        <location filename="../utilities.cpp" line="164"/>
+        <source>Create Folder</source>
+        <translation>Создать папку</translation>
+    </message>
+    <message>
+        <location filename="../utilities.cpp" line="169"/>
         <source>Please enter a new file name:</source>
         <translation>Введите имя нового файла:</translation>
     </message>
     <message>
-        <location filename="../utilities.cpp" line="168"/>
+        <location filename="../utilities.cpp" line="170"/>
         <source>New text file</source>
         <translation>Новый текстовый файл</translation>
     </message>
     <message>
-        <location filename="../utilities.cpp" line="172"/>
+        <location filename="../utilities.cpp" line="174"/>
         <source>Please enter a new folder name:</source>
         <translation>Введите имя новой папки:</translation>
     </message>
     <message>
-        <location filename="../utilities.cpp" line="173"/>
+        <location filename="../utilities.cpp" line="175"/>
         <source>New folder</source>
         <translation>Новая папка</translation>
     </message>
     <message>
-        <location filename="../utilities.cpp" line="178"/>
+        <location filename="../utilities.cpp" line="180"/>
         <source>Enter a name for the new %1:</source>
         <translation>Введите имя для нового %1:</translation>
     </message>
     <message>
-        <location filename="../utilities.cpp" line="187"/>
+        <location filename="../utilities.cpp" line="165"/>
         <source>Create File</source>
         <translation>Создать файл</translation>
     </message>
@@ -1028,4 +1097,181 @@ Modified: %3</source>
         <translation>Запомнить выбор для всех уже существующих файлов</translation>
     </message>
 </context>
+<context>
+    <name>SearchDialog</name>
+    <message>
+        <location filename="../filesearch.ui" line="14"/>
+        <source>Search Files</source>
+        <translation>Искать файлы</translation>
+    </message>
+    <message>
+        <location filename="../filesearch.ui" line="29"/>
+        <source>Name/Location</source>
+        <translation>Имя/Расположение</translation>
+    </message>
+    <message>
+        <location filename="../filesearch.ui" line="35"/>
+        <source>File Name Patterns:</source>
+        <translation>Шаблоны имени файла:</translation>
+    </message>
+    <message>
+        <location filename="../filesearch.ui" line="41"/>
+        <source>*</source>
+        <translation></translation>
+    </message>
+    <message>
+        <location filename="../filesearch.ui" line="48"/>
+        <source>Case insensitive</source>
+        <translation>Нечувствительный к регистру поиск</translation>
+    </message>
+    <message>
+        <location filename="../filesearch.ui" line="55"/>
+        <source>Use regular expression</source>
+        <translation>Использовать регулярные выражения</translation>
+    </message>
+    <message>
+        <location filename="../filesearch.ui" line="65"/>
+        <source>Places to Search:</source>
+        <translation>Места для поиска:</translation>
+    </message>
+    <message>
+        <location filename="../filesearch.ui" line="78"/>
+        <source>&amp;Add</source>
+        <translation>&amp;Добавить</translation>
+    </message>
+    <message>
+        <location filename="../filesearch.ui" line="90"/>
+        <source>&amp;Remove</source>
+        <translation>&amp;Удалить</translation>
+    </message>
+    <message>
+        <location filename="../filesearch.ui" line="119"/>
+        <source>Search in sub directories</source>
+        <translation>Искать в подпапках</translation>
+    </message>
+    <message>
+        <location filename="../filesearch.ui" line="126"/>
+        <source>Search for hidden files</source>
+        <translation>Искать скрытые файлы</translation>
+    </message>
+    <message>
+        <location filename="../filesearch.ui" line="137"/>
+        <source>File Type</source>
+        <translation>Тип файла</translation>
+    </message>
+    <message>
+        <location filename="../filesearch.ui" line="143"/>
+        <source>Only search for files of following types:</source>
+        <translation>Искать файлы только следующих типов:</translation>
+    </message>
+    <message>
+        <location filename="../filesearch.ui" line="149"/>
+        <source>Text files</source>
+        <translation>Текстовые файлы</translation>
+    </message>
+    <message>
+        <location filename="../filesearch.ui" line="156"/>
+        <source>Image files</source>
+        <translation>Изображения</translation>
+    </message>
+    <message>
+        <location filename="../filesearch.ui" line="163"/>
+        <source>Audio files</source>
+        <translation>Аудиофайлы</translation>
+    </message>
+    <message>
+        <location filename="../filesearch.ui" line="170"/>
+        <source>Video files</source>
+        <translation>Видеофайлы</translation>
+    </message>
+    <message>
+        <location filename="../filesearch.ui" line="177"/>
+        <source>Documents</source>
+        <translation>Документы</translation>
+    </message>
+    <message>
+        <location filename="../filesearch.ui" line="184"/>
+        <source>Folders</source>
+        <translation>Папки</translation>
+    </message>
+    <message>
+        <location filename="../filesearch.ui" line="208"/>
+        <source>Content</source>
+        <translation>Содержание</translation>
+    </message>
+    <message>
+        <location filename="../filesearch.ui" line="214"/>
+        <source>File contains:</source>
+        <translation>Файл содержит:</translation>
+    </message>
+    <message>
+        <location filename="../filesearch.ui" line="223"/>
+        <source>Case insensiti&amp;ve</source>
+        <translation>Нечувствительн&amp;ый к регистру поиск</translation>
+    </message>
+    <message>
+        <location filename="../filesearch.ui" line="230"/>
+        <source>&amp;Use regular expression</source>
+        <translation>&amp;Использовать регулярные выражения</translation>
+    </message>
+    <message>
+        <location filename="../filesearch.ui" line="254"/>
+        <source>Properties</source>
+        <translation>Свойства</translation>
+    </message>
+    <message>
+        <location filename="../filesearch.ui" line="260"/>
+        <source>File Size:</source>
+        <translation>Размер файла:</translation>
+    </message>
+    <message>
+        <location filename="../filesearch.ui" line="266"/>
+        <source>Larger than:</source>
+        <translation>Больше, чем:</translation>
+    </message>
+    <message>
+        <location filename="../filesearch.ui" line="282"/>
+        <location filename="../filesearch.ui" line="323"/>
+        <source>Bytes</source>
+        <translation>Байт</translation>
+    </message>
+    <message>
+        <location filename="../filesearch.ui" line="287"/>
+        <location filename="../filesearch.ui" line="328"/>
+        <source>KiB</source>
+        <translation>КиБ</translation>
+    </message>
+    <message>
+        <location filename="../filesearch.ui" line="292"/>
+        <location filename="../filesearch.ui" line="333"/>
+        <source>MiB</source>
+        <translation>МиБ</translation>
+    </message>
+    <message>
+        <location filename="../filesearch.ui" line="297"/>
+        <location filename="../filesearch.ui" line="338"/>
+        <source>GiB</source>
+        <translation>ГиБ</translation>
+    </message>
+    <message>
+        <location filename="../filesearch.ui" line="307"/>
+        <source>Smaller than:</source>
+        <translation>Меньше, чем:</translation>
+    </message>
+    <message>
+        <location filename="../filesearch.ui" line="351"/>
+        <source>Last Modified Time:</source>
+        <translation>Время последнего изменения:</translation>
+    </message>
+    <message>
+        <location filename="../filesearch.ui" line="357"/>
+        <source>Earlier than:</source>
+        <translation>Раньше, чем:</translation>
+    </message>
+    <message>
+        <location filename="../filesearch.ui" line="364"/>
+        <source>Later than:</source>
+        <translation>Позже, чем:</translation>
+    </message>
+</context>
 </TS>
