@@ -32,7 +32,9 @@
 #include <QFile>
 #include <QMessageBox>
 #include <QCommandLineParser>
+#include <QSocketNotifier>
 #include <gio/gio.h>
+#include <sys/socket.h>
 
 #include "applicationadaptor.h"
 #include "preferencesdialog.h"
@@ -40,12 +42,16 @@
 #include "mountoperation.h"
 #include "autorundialog.h"
 #include "launcher.h"
+#include "filesearchdialog.h"
 
 #include <QScreen>
 #include <QWindow>
 
 #include <X11/Xlib.h>
 
+#include "xdgdir.h"
+#include <QFileSystemWatcher>
+
 using namespace PCManFM;
 static const char* serviceName = "org.pcmanfm.PCManFM";
 static const char* ifaceName = "org.pcmanfm.Application";
@@ -67,6 +73,8 @@ Application::Application(int& argc, char** argv):
   enableDesktopManager_(false),
   preferencesDialog_(),
   volumeMonitor_(NULL),
+  userDirsWatcher_(NULL),
+  lxqtRunning_(false),
   editBookmarksialog_() {
 
   argc_ = argc;
@@ -84,6 +92,8 @@ Application::Application(int& argc, char** argv):
     dbus.registerObject("/Application", this);
 
     connect(this, &Application::aboutToQuit, this, &Application::onAboutToQuit);
+    // aboutToQuit() is not signalled on SIGTERM, install signal handler
+    installSigtermHandler();
     settings_.load(profileName_);
 
     // decrease the cache size to reduce memory usage
@@ -93,6 +103,21 @@ Application::Application(int& argc, char** argv):
       QIcon::setThemeName(settings_.fallbackIconThemeName());
       Fm::IconTheme::checkChanged();
     }
+
+    // Check if LXQt Session is running. LXQt has it's own Desktop Folder
+    // editor. We just hide our editor when LXQt is running.
+    QDBusInterface* lxqtSessionIface = new QDBusInterface(
+                                        QStringLiteral("org.lxqt.session"),
+                                        QStringLiteral("/LXQtSession"));
+    if (lxqtSessionIface) {
+      if (lxqtSessionIface->isValid()) {
+          lxqtRunning_ = true;
+          userDesktopFolder_ = XdgDir::readDesktopDir();
+          initWatch();
+      }
+      delete lxqtSessionIface;
+      lxqtSessionIface = 0;
+    }
   }
   else {
     // an service of the same name is already registered.
@@ -109,8 +134,23 @@ Application::~Application() {
     g_object_unref(volumeMonitor_);
   }
 
-  if(enableDesktopManager_)
-    removeNativeEventFilter(this);
+  // if(enableDesktopManager_)
+  //   removeNativeEventFilter(this);
+}
+
+void Application::initWatch()
+{
+  QFile file_ (QStandardPaths::writableLocation(QStandardPaths::ConfigLocation) + QStringLiteral("/user-dirs.dirs"));
+  if(! file_.open(QIODevice::ReadOnly | QIODevice::Text)) {
+    qDebug() << Q_FUNC_INFO << "Could not read: " << userDirsFile_;
+    userDirsFile_ = QString();
+  } else {
+    userDirsFile_ = file_.fileName();
+  }
+
+  userDirsWatcher_ = new QFileSystemWatcher(this);
+  userDirsWatcher_->addPath(userDirsFile_);
+  connect(userDirsWatcher_, &QFileSystemWatcher::fileChanged, this, &Application::onUserDirsChanged);
 }
 
 bool Application::parseCommandLineArgs() {
@@ -200,7 +240,7 @@ bool Application::parseCommandLineArgs() {
             paths.push_back(QDir::currentPath());
         }
         if(!paths.isEmpty())
-          launchFiles(paths, parser.isSet(newWindowOption));
+          launchFiles(QDir::currentPath(), paths, parser.isSet(newWindowOption));
         keepRunning = true;
       }
     }
@@ -235,8 +275,8 @@ bool Application::parseCommandLineArgs() {
         QStringList paths = parser.positionalArguments();
         if(paths.isEmpty()) {
           paths.push_back(QDir::currentPath());
-	}
-        iface.call("launchFiles", paths, parser.isSet(newWindowOption));
+        }
+        iface.call("launchFiles", QDir::currentPath(), paths, parser.isSet(newWindowOption));
       }
     }
   }
@@ -277,6 +317,32 @@ int Application::exec() {
   return QCoreApplication::exec();
 }
 
+
+void Application::onUserDirsChanged()
+{
+  qDebug() << Q_FUNC_INFO;
+  bool file_deleted = !userDirsWatcher_->files().contains(userDirsFile_);
+  if(file_deleted) {
+    // if our config file is already deleted, reinstall a new watcher
+    userDirsWatcher_->addPath(userDirsFile_);
+  }
+
+  const QString d = XdgDir::readDesktopDir();
+  if (d != userDesktopFolder_) {
+    userDesktopFolder_ = d;
+    const QDir dir(d);
+    if (dir.exists()) {
+      const int N = desktopWindows_.size();
+      for(int i = 0; i < N; ++i) {
+        desktopWindows_.at(i)->setDesktopFolder();
+      }
+    } else {
+        qWarning("Application::onUserDirsChanged: %s doesn't exist",
+                    qUtf8Printable(userDesktopFolder_));
+    }
+  }
+}
+
 void Application::onAboutToQuit() {
   qDebug("aboutToQuit");
   settings_.save();
@@ -307,7 +373,7 @@ void Application::desktopManager(bool enabled) {
   QDesktopWidget* desktopWidget = desktop();
   if(enabled) {
     if(!enableDesktopManager_) {
-      installNativeEventFilter(this);
+      // installNativeEventFilter(this);
       Q_FOREACH(QScreen* screen, screens()) {
         connect(screen, &QScreen::virtualGeometryChanged, this, &Application::onVirtualGeometryChanged);
         connect(screen, &QObject::destroyed, this, &Application::onScreenDestroyed);
@@ -348,7 +414,7 @@ void Application::desktopManager(bool enabled) {
         disconnect(screen, &QObject::destroyed, this, &Application::onScreenDestroyed);
       }
       disconnect(this, &QApplication::screenAdded, this, &Application::onScreenAdded);
-      removeNativeEventFilter(this);
+      // removeNativeEventFilter(this);
     }
   }
   enableDesktopManager_ = enabled;
@@ -358,6 +424,9 @@ void Application::desktopPrefrences(QString page) {
   // show desktop preference window
   if(!desktopPreferencesDialog_) {
     desktopPreferencesDialog_ = new DesktopPreferencesDialog();
+
+    // Should be used only one time
+    desktopPreferencesDialog_->setEditDesktopFolder(!lxqtRunning_);
   }
   desktopPreferencesDialog_.data()->selectPage(page);
   desktopPreferencesDialog_.data()->show();
@@ -365,20 +434,49 @@ void Application::desktopPrefrences(QString page) {
   desktopPreferencesDialog_.data()->activateWindow();
 }
 
-void Application::findFiles(QStringList paths) {
-  // TODO: add a file searching utility here.
-  qDebug("findFiles");
+void Application::onFindFileAccepted() {
+  Fm::FileSearchDialog* dlg = static_cast<Fm::FileSearchDialog*>(sender());
+  Fm::Path uri = dlg->searchUri();
+  // FIXME: we should be able to open it in an existing window
+  FmPathList* paths = fm_path_list_new();
+  fm_path_list_push_tail(paths, uri.data());
+  Launcher(NULL).launchPaths(NULL, paths);
+  fm_path_list_unref(paths);
 }
 
-void Application::launchFiles(QStringList paths, bool inNewWindow) {
+void Application::findFiles(QStringList paths) {
+  // launch file searching utility.
+  Fm::FileSearchDialog* dlg = new Fm::FileSearchDialog(paths);
+  connect(dlg, &QDialog::accepted, this, &Application::onFindFileAccepted);
+  dlg->setAttribute(Qt::WA_DeleteOnClose);
+  dlg->show();
+}
+
+void Application::launchFiles(QString cwd, QStringList paths, bool inNewWindow) {
   FmPathList* pathList = fm_path_list_new();
+  FmPath* cwd_path = NULL;
   QStringList::iterator it;
-  for(it = paths.begin(); it != paths.end(); ++it) {
-    QString& pathName = *it;
-    FmPath* path = fm_path_new_for_commandline_arg(pathName.toLocal8Bit().constData());
+  Q_FOREACH(const QString& it, paths) {
+    QByteArray pathName = it.toLocal8Bit();
+    FmPath* path = NULL;
+    if(pathName[0] == '/') // absolute path
+        path = fm_path_new_for_path(pathName.constData());
+    else if(pathName.contains(":/")) // URI
+        path = fm_path_new_for_uri(pathName.constData());
+    else if(pathName == "~") // special case for home dir
+        path = fm_path_ref(fm_path_get_home());
+    else // basename
+    {
+        if(Q_UNLIKELY(!cwd_path))
+            cwd_path = fm_path_new_for_str(cwd.toLocal8Bit().constData());
+        path = fm_path_new_relative(cwd_path, pathName.constData());
+    }
     fm_path_list_push_tail(pathList, path);
     fm_path_unref(path);
   }
+  if(cwd_path)
+      fm_path_unref(cwd_path);
+
   Launcher(NULL).launchPaths(NULL, pathList);
   fm_path_list_unref(pathList);
 }
@@ -615,17 +713,18 @@ void Application::onVolumeAdded(GVolumeMonitor* monitor, GVolume* volume, Applic
     pThis->autoMountVolume(volume, true);
 }
 
+#if 0
 bool Application::nativeEventFilter(const QByteArray & eventType, void * message, long * result) {
   if(eventType == "xcb_generic_event_t") { // XCB event
     // filter all native X11 events (xcb)
     xcb_generic_event_t* generic_event = reinterpret_cast<xcb_generic_event_t*>(message);
     // qDebug("XCB event: %d", generic_event->response_type & ~0x80);
     Q_FOREACH(DesktopWindow * window, desktopWindows_) {
-      window->xcbEvent(generic_event);
     }
   }
   return false;
 }
+#endif
 
 void Application::onScreenAdded(QScreen* newScreen) {
   if(enableDesktopManager_) {
@@ -659,7 +758,6 @@ void Application::onScreenDestroyed(QObject* screenObj) {
   //
   // The workaround is very simple. Just completely destroy the window before Qt has a chance to do
   // QWindow::setScreen() for it. Later, we recreate the window ourselves. So this can bypassing the Qt bugs.
-  QScreen* screen = static_cast<QScreen*>(screenObj);
   if(enableDesktopManager_) {
     bool reloadNeeded = false;
     // FIXME: add workarounds for Qt5 bug #40681 and #40791 here.
@@ -699,10 +797,44 @@ void Application::onVirtualGeometryChanged(const QRect& rect) {
   // virtualGeometryChanged() is emitted correctly when the workAreas changed.
   // So we use it in Qt5.
   if(enableDesktopManager_) {
-    QScreen* screeb = static_cast<QScreen*>(sender());
     // qDebug() << "onVirtualGeometryChanged";
     Q_FOREACH(DesktopWindow* desktop, desktopWindows_) {
       desktop->queueRelayout();
     }
   }
 }
+
+
+static int sigterm_fd[2];
+
+static void sigtermHandler(int) {
+  char c = 1;
+  ::write(sigterm_fd[0], &c, sizeof(c));
+}
+
+void Application::installSigtermHandler() {
+  if(::socketpair(AF_UNIX, SOCK_STREAM, 0, sigterm_fd) == 0) {
+    QSocketNotifier* notifier = new QSocketNotifier(sigterm_fd[1], QSocketNotifier::Read, this);
+    connect(notifier, &QSocketNotifier::activated, this, &Application::onSigtermNotified);
+
+    struct sigaction action;
+    action.sa_handler = sigtermHandler;
+    ::sigemptyset(&action.sa_mask);
+    action.sa_flags |= SA_RESTART;
+    if(::sigaction(SIGTERM, &action, 0) != 0) {
+      qWarning("Couldn't install SIGTERM handler");
+    }
+  } else {
+    qWarning("Couldn't create SIGTERM socketpair");
+  }
+}
+
+void Application::onSigtermNotified() {
+  if (QSocketNotifier* notifier = qobject_cast<QSocketNotifier*>(sender())) {
+    notifier->setEnabled(false);
+    char c;
+    ::read(sigterm_fd[1], &c, sizeof(c));
+    quit();
+    notifier->setEnabled(true);
+  }
+}
