@@ -21,6 +21,7 @@
 #include "desktopwindow.h"
 #include "settings.h"
 #include "application.h"
+#include "xdgdir.h"
 #include <QFileDialog>
 #include <QImageReader>
 #include <QFile>
@@ -32,56 +33,12 @@
 
 using namespace PCManFM;
 
-static QString readUserDirsFile() {
-  QFile file(QStandardPaths::writableLocation(QStandardPaths::ConfigLocation) + QStringLiteral("/user-dirs.dirs"));
-  if(file.open(QIODevice::ReadOnly | QIODevice::Text)) {
-    QByteArray data = file.readAll();
-    file.close();
-    return QString::fromLocal8Bit(data);
-  }
-  return QString();
-}
-
-static QString readDesktopDir() {
-  QString str = readUserDirsFile();
-  if(str.isEmpty())
-    return QStandardPaths::writableLocation(QStandardPaths::HomeLocation) + QStringLiteral("/Desktop");
-  QRegExp reg(QStringLiteral("XDG_DESKTOP_DIR=\"([^\n]*)\""));
-  if(reg.lastIndexIn(str) != -1) {
-    str = reg.cap(1);
-    if(str.startsWith(QStringLiteral("$HOME")))
-      str = QStandardPaths::writableLocation(QStandardPaths::HomeLocation) + str.mid(5);
-    return str;
-  }
-  return QString();
-}
-
-static void setDesktopDir(QString path) {
-  QString home = QStandardPaths::writableLocation(QStandardPaths::HomeLocation);
-  if(path.startsWith(home))
-    path = QStringLiteral("$HOME") + path.mid(home.length());
-  QString str = readUserDirsFile();
-  QRegExp reg(QStringLiteral("XDG_DESKTOP_DIR=\"([^\n]*)\""));
-  QString line = QStringLiteral("XDG_DESKTOP_DIR=\"") + path + '\"';
-  if(reg.indexIn(str) != -1)
-    str.replace(reg, line);
-  else {
-	if(!str.endsWith('\n'))
-	  str += '\n';
-    str += line + '\n';
-  }
-  QString dir = QStandardPaths::writableLocation(QStandardPaths::ConfigLocation);
-  if(QDir().mkpath(dir)) { // write the file
-    QSaveFile file(dir + QStringLiteral("/user-dirs.dirs"));
-    if(file.open(QIODevice::WriteOnly | QIODevice::Text)) {
-      file.write(str.toLocal8Bit());
-      file.commit();
-    }
-  }
-}
-
 DesktopPreferencesDialog::DesktopPreferencesDialog(QWidget* parent, Qt::WindowFlags f):
-  QDialog(parent, f) {
+  QDialog(parent, f),
+  editDesktopFolderEnabled(false),
+  desktopFolderWidget(0),
+  desktopFolder() {
+
 
   setAttribute(Qt::WA_DeleteOnClose);
 
@@ -121,26 +78,42 @@ DesktopPreferencesDialog::DesktopPreferencesDialog(QWidget* parent, Qt::WindowFl
   qDebug("wallpaper: %s", settings.wallpaper().toUtf8().data());
   ui.imageFile->setText(settings.wallpaper());
 
-  connect(ui.browseDesktopFolder, &QPushButton::clicked, this, &DesktopPreferencesDialog::onBrowseDesktopFolderClicked);
-  QString desktopFolder = readDesktopDir();
-  qDebug("desktop folder: %s", desktopFolder.toStdString().c_str());
-  ui.desktopFolder->setText(desktopFolder);
-
   ui.font->setFont(settings.desktopFont());
 
   ui.backgroundColor->setColor(settings.desktopBgColor());
   ui.textColor->setColor(settings.desktopFgColor());
   ui.shadowColor->setColor(settings.desktopShadowColor());
   ui.showWmMenu->setChecked(settings.showWmMenu());
+
+  connect(ui.buttonBox->button(QDialogButtonBox::Apply), &QPushButton::clicked,
+          this, &DesktopPreferencesDialog::onApplyClicked);
 }
 
 DesktopPreferencesDialog::~DesktopPreferencesDialog() {
 }
 
-void DesktopPreferencesDialog::accept() {
+void DesktopPreferencesDialog::setupDesktopFolderUi()
+{
+  desktopFolderWidget = new QWidget();
+  uiDesktopFolder.setupUi(desktopFolderWidget);
+  ui.advancedPageLayout->insertWidget(1, desktopFolderWidget);
+  uiDesktopFolder.verticalLayout->setMargin(0);
+
+  desktopFolder = XdgDir::readDesktopDir();
+  qDebug("desktop folder: %s", desktopFolder.toStdString().c_str());
+
+  uiDesktopFolder.desktopFolder->setText(desktopFolder);
+
+  connect(uiDesktopFolder.browseDesktopFolder, &QPushButton::clicked,
+    this, &DesktopPreferencesDialog::onBrowseDesktopFolderClicked);
+}
+
+void DesktopPreferencesDialog::applySettings()
+{
   Settings& settings = static_cast<Application*>(qApp)->settings();
 
-  setDesktopDir(ui.desktopFolder->text());
+  if (editDesktopFolderEnabled)
+      XdgDir::setDesktopDir(uiDesktopFolder.desktopFolder->text());
 
   settings.setWallpaper(ui.imageFile->text());
   int mode = ui.wallpaperMode->itemData(ui.wallpaperMode->currentIndex()).toInt();
@@ -151,14 +124,22 @@ void DesktopPreferencesDialog::accept() {
   settings.setDesktopShadowColor(ui.shadowColor->color());
   settings.setShowWmMenu(ui.showWmMenu->isChecked());
 
-  QDialog::accept();
-
-  static_cast<Application*>(qApp)->updateDesktopsFromSettings();
   settings.save();
 }
 
+void DesktopPreferencesDialog::onApplyClicked()
+{
+  applySettings();
+  static_cast<Application*>(qApp)->updateDesktopsFromSettings();
+}
+
+void DesktopPreferencesDialog::accept() {
+  applySettings();
+  static_cast<Application*>(qApp)->updateDesktopsFromSettings();
+  QDialog::accept();
+}
+
 void DesktopPreferencesDialog::onWallpaperModeChanged(int index) {
-  int n = ui.wallpaperMode->count();
   int mode = ui.wallpaperMode->itemData(index).toInt();
 
   bool enable = (mode != DesktopWindow::WallpaperNone);
@@ -195,11 +176,12 @@ void DesktopPreferencesDialog::onBrowseDesktopFolderClicked()
 {
   QFileDialog dlg;
   dlg.setAcceptMode(QFileDialog::AcceptOpen);
+  dlg.setAcceptMode(QFileDialog::AcceptOpen);
   dlg.setFileMode(QFileDialog::DirectoryOnly);
   if (dlg.exec() == QDialog::Accepted) {
     QString dir;
     dir = dlg.selectedFiles().first();
-    ui.desktopFolder->setText(dir);
+    uiDesktopFolder.desktopFolder->setText(dir);
   }
 }
 
@@ -208,3 +190,10 @@ void DesktopPreferencesDialog::selectPage(QString name) {
   if(page)
     ui.tabWidget->setCurrentWidget(page);
 }
+
+void DesktopPreferencesDialog::setEditDesktopFolder(const bool enabled)
+{
+  editDesktopFolderEnabled = enabled;
+  if (editDesktopFolderEnabled)
+      setupDesktopFolderUi();
+}
