@@ -59,12 +59,16 @@ MainWindow::MainWindow(FmPath* path):
   ui.setupUi(this);
 
   // hide menu items that are not usable
-  if(!isUriSchemeSupported("computer"))
-    ui.actionComputer->setVisible(false);
-  if(!isUriSchemeSupported("trash"))
+  //if(!uriExists("computer:///"))
+  //  ui.actionComputer->setVisible(false);
+  if(!settings.supportTrash())
     ui.actionTrash->setVisible(false);
-  if(!isUriSchemeSupported("network"))
-    ui.actionNetwork->setVisible(false);
+
+  // FIXME: add an option to hide network:///
+  // We cannot use uriExists() here since calling this on "network:///"
+  // is very slow and blocking.
+  //if(!uriExists("network:///"))
+  //  ui.actionNetwork->setVisible(false);
 
   // add a context menu for showing browse history to back and forward buttons
   QToolButton* forwardButton = static_cast<QToolButton*>(ui.toolBar->widgetForAction(ui.actionGoForward));
@@ -92,10 +96,21 @@ MainWindow::MainWindow(FmPath* path):
   connect(ui.tabBar, &QTabBar::tabMoved, this, &MainWindow::onTabBarTabMoved);
   connect(ui.stackedWidget, &QStackedWidget::widgetRemoved, this, &MainWindow::onStackedWidgetWidgetRemoved);
 
+  // FIXME: should we make the filter bar a per-view configuration?
+  ui.filterBar->setVisible(settings.showFilter());
+  ui.actionFilter->setChecked(settings.showFilter());
+  connect(ui.filterBar, &QLineEdit::textChanged, this, &MainWindow::onFilterStringChanged);
+
   // side pane
   ui.sidePane->setIconSize(QSize(settings.sidePaneIconSize(), settings.sidePaneIconSize()));
-  ui.sidePane->setMode(Fm::SidePane::ModePlaces);
+  ui.sidePane->setMode(settings.sidePaneMode());
   connect(ui.sidePane, &Fm::SidePane::chdirRequested, this, &MainWindow::onSidePaneChdirRequested);
+  connect(ui.sidePane, &Fm::SidePane::openFolderInNewWindowRequested, this, &MainWindow::onSidePaneOpenFolderInNewWindowRequested);
+  connect(ui.sidePane, &Fm::SidePane::openFolderInNewTabRequested, this, &MainWindow::onSidePaneOpenFolderInNewTabRequested);
+  connect(ui.sidePane, &Fm::SidePane::openFolderInTerminalRequested, this, &MainWindow::onSidePaneOpenFolderInTerminalRequested);
+  connect(ui.sidePane, &Fm::SidePane::createNewFolderRequested, this, &MainWindow::onSidePaneCreateNewFolderRequested);
+  connect(ui.sidePane, &Fm::SidePane::modeChanged, this, &MainWindow::onSidePaneModeChanged);
+
   // detect change of splitter position
   connect(ui.splitter, &QSplitter::splitterMoved, this, &MainWindow::onSplitterMoved);
 
@@ -171,8 +186,21 @@ MainWindow::MainWindow(FmPath* path):
   shortcut = new QShortcut(QKeySequence(Qt::SHIFT + Qt::Key_Delete), this);
   connect(shortcut, &QShortcut::activated, this, &MainWindow::on_actionDelete_triggered);
 
+  if(QToolButton* clearButton = ui.filterBar->findChild<QToolButton*>()) {
+    clearButton->setToolTip(tr("Clear text (Ctrl+K)"));
+    shortcut = new QShortcut(Qt::CTRL + Qt::Key_K, this);
+    connect(shortcut, &QShortcut::activated, ui.filterBar, &QLineEdit::clear);
+  }
+
   if(path)
     addTab(path);
+
+  // size from settings
+  if(settings.rememberWindowSize()) {
+    resize(settings.windowWidth(), settings.windowHeight());
+    if(settings.windowMaximized())
+      setWindowState(windowState() | Qt::WindowMaximized);
+  }
 }
 
 MainWindow::~MainWindow() {
@@ -184,6 +212,7 @@ void MainWindow::chdir(FmPath* path) {
   TabPage* page = currentPage();
 
   if(page) {
+    ui.filterBar->clear();
     page->chdir(path, true);
     updateUIForCurrentPage();
   }
@@ -200,6 +229,8 @@ void MainWindow::addTab(FmPath* path) {
   connect(newPage, &TabPage::statusChanged, this, &MainWindow::onTabPageStatusChanged);
   connect(newPage, &TabPage::openDirRequested, this, &MainWindow::onTabPageOpenDirRequested);
   connect(newPage, &TabPage::sortFilterChanged, this, &MainWindow::onTabPageSortFilterChanged);
+  connect(newPage, &TabPage::backwardRequested, this, &MainWindow::on_actionGoBack_triggered);
+  connect(newPage, &TabPage::forwardRequested, this, &MainWindow::on_actionGoForward_triggered);
 
   ui.tabBar->insertTab(index, newPage->title());
 
@@ -220,6 +251,7 @@ void MainWindow::on_actionGoUp_triggered() {
   TabPage* page = currentPage();
 
   if(page) {
+    ui.filterBar->clear();
     page->up();
     updateUIForCurrentPage();
   }
@@ -229,6 +261,7 @@ void MainWindow::on_actionGoBack_triggered() {
   TabPage* page = currentPage();
 
   if(page) {
+    ui.filterBar->clear();
     page->backward();
     updateUIForCurrentPage();
   }
@@ -238,6 +271,7 @@ void MainWindow::on_actionGoForward_triggered() {
   TabPage* page = currentPage();
 
   if(page) {
+    ui.filterBar->clear();
     page->forward();
     updateUIForCurrentPage();
   }
@@ -262,14 +296,25 @@ void MainWindow::on_actionNewTab_triggered() {
 
 void MainWindow::on_actionNewWin_triggered() {
   FmPath* path = currentPage()->path();
-  Application* app = static_cast<Application*>(qApp);
-  MainWindow* newWin = new MainWindow(path);
-  newWin->resize(app->settings().windowWidth(), app->settings().windowHeight());
+  (new MainWindow(path))->show();
+}
 
-  if(app->settings().windowMaximized())
-  	newWin->setWindowState(newWin->windowState() | Qt::WindowMaximized);
-  
-  newWin->show();
+void MainWindow::on_actionNewFolder_triggered() {
+  if(TabPage* tabPage = currentPage()) {
+    FmPath* dirPath = tabPage->folderView()->path();
+
+    if(dirPath)
+      createFileOrFolder(CreateNewFolder, dirPath);
+  }
+}
+
+void MainWindow::on_actionNewBlankFile_triggered() {
+  if(TabPage* tabPage = currentPage()) {
+    FmPath* dirPath = tabPage->folderView()->path();
+
+    if(dirPath)
+      createFileOrFolder(CreateNewTextFile, dirPath);
+  }
 }
 
 void MainWindow::on_actionCloseTab_triggered() {
@@ -313,6 +358,7 @@ void MainWindow::on_actionFolderProperties_triggered() {
 void MainWindow::on_actionShowHidden_triggered(bool checked) {
   TabPage* tabPage = currentPage();
   tabPage->setShowHidden(checked);
+  ui.sidePane->setShowHidden(checked);
   static_cast<Application*>(qApp)->settings().setShowHidden(checked);
 }
 
@@ -352,6 +398,11 @@ void MainWindow::on_actionFolderFirst_triggered(bool checked) {
   currentPage()->setSortFolderFirst(checked);
 }
 
+void MainWindow::on_actionFilter_triggered(bool checked) {
+  ui.filterBar->setVisible(checked);
+  static_cast<Application*>(qApp)->settings().setShowFilter(checked);
+}
+
 void MainWindow::on_actionComputer_triggered() {
   FmPath* path = fm_path_new_for_uri("computer:///");
   chdir(path);
@@ -446,6 +497,16 @@ void MainWindow::onTabBarTabMoved(int from, int to) {
   }
 }
 
+void MainWindow::onFilterStringChanged(QString str) {
+  if(TabPage* tabPage = currentPage()) {
+    // appy filter only if needed (not if tab is changed)
+    if(str != tabPage->getFilterStr()) {
+      tabPage->setFilterStr(str);
+      tabPage->applyFilter();
+    }
+  }
+}
+
 void MainWindow::closeTab(int index) {
   QWidget* page = ui.stackedWidget->widget(index);
   if(page) {
@@ -485,6 +546,8 @@ void MainWindow::closeEvent(QCloseEvent *event)
 
 void MainWindow::onTabBarCurrentChanged(int index) {
   ui.stackedWidget->setCurrentIndex(index);
+  if(TabPage* page = static_cast<TabPage*>(ui.stackedWidget->widget(index)))
+    ui.filterBar->setText(page->getFilterStr());
   updateUIForCurrentPage();
 }
 
@@ -562,6 +625,7 @@ void MainWindow::updateUIForCurrentPage() {
 
     // update side pane
     ui.sidePane->setCurrentPath(tabPage->path());
+    ui.sidePane->setShowHidden(tabPage->showHidden());
 
     // update back/forward/up toolbar buttons
     ui.actionGoUp->setEnabled(tabPage->canUp());
@@ -573,7 +637,6 @@ void MainWindow::updateUIForCurrentPage() {
   }
 }
 
-
 void MainWindow::onStackedWidgetWidgetRemoved(int index) {
   // qDebug("onStackedWidgetWidgetRemoved: %d", index);
   // need to remove associated tab from tabBar
@@ -625,24 +688,16 @@ void MainWindow::onTabPageStatusChanged(int type, QString statusText) {
 
 void MainWindow::onTabPageOpenDirRequested(FmPath* path, int target) {
   switch(target) {
-  case View::OpenInCurrentView:
+  case OpenInCurrentTab:
     chdir(path);
     break;
 
-  case View::OpenInNewTab:
+  case OpenInNewTab:
     addTab(path);
     break;
 
-  case View::OpenInNewWindow: {
-    Application* app = static_cast<Application*>(qApp);
-    MainWindow* newWin = new MainWindow(path);
-    // TODO: apply window size from app->settings
-    newWin->resize(app->settings().windowWidth(), app->settings().windowHeight());
-    
-    if(app->settings().windowMaximized())
-        newWin->setWindowState(newWin->windowState() | Qt::WindowMaximized);
-    
-    newWin->show();
+  case OpenInNewWindow: {
+    (new MainWindow(path))->show();
     break;
   }
   }
@@ -653,6 +708,10 @@ void MainWindow::onTabPageSortFilterChanged() {
 
   if(tabPage == currentPage()) {
     updateViewMenuForCurrentPage();
+    Settings& settings = static_cast<Application*>(qApp)->settings();
+    settings.setSortColumn(static_cast<Fm::FolderModel::ColumnId>(tabPage->sortColumn()));
+    settings.setSortOrder(tabPage->sortOrder());
+    settings.setSortFolderFirst(tabPage->sortFolderFirst());
   }
 }
 
@@ -663,6 +722,29 @@ void MainWindow::onSidePaneChdirRequested(int type, FmPath* path) {
     chdir(path);
   else if(type == 1) // middle button
     addTab(path);
+  else if(type == 2) // new window
+    (new MainWindow(path))->show();
+}
+
+void MainWindow::onSidePaneOpenFolderInNewWindowRequested(FmPath* path) {
+  (new MainWindow(path))->show();
+}
+
+void MainWindow::onSidePaneOpenFolderInNewTabRequested(FmPath* path) {
+  addTab(path);
+}
+
+void MainWindow::onSidePaneOpenFolderInTerminalRequested(FmPath* path) {
+  Application* app = static_cast<Application*>(qApp);
+  app->openFolderInTerminal(path);
+}
+
+void MainWindow::onSidePaneCreateNewFolderRequested(FmPath* path) {
+  createFileOrFolder(CreateNewFolder, path);
+}
+
+void MainWindow::onSidePaneModeChanged(Fm::SidePane::Mode mode) {
+  static_cast<Application*>(qApp)->settings().setSidePaneMode(mode);
 }
 
 void MainWindow::onSplitterMoved(int pos, int index) {
@@ -671,17 +753,18 @@ void MainWindow::onSplitterMoved(int pos, int index) {
 }
 
 void MainWindow::loadBookmarksMenu() {
-  GList* l = fm_bookmarks_get_all(bookmarks);
+  GList* allBookmarks = fm_bookmarks_get_all(bookmarks);
   QAction* before = ui.actionAddToBookmarks;
 
-  for(; l; l = l->next) {
+  for(GList* l = allBookmarks; l; l = l->next) {
     FmBookmarkItem* item = reinterpret_cast<FmBookmarkItem*>(l->data);
-    BookmarkAction* action = new BookmarkAction(item);
+    BookmarkAction* action = new BookmarkAction(item, ui.menu_Bookmarks);
     connect(action, &QAction::triggered, this, &MainWindow::onBookmarkActionTriggered);
     ui.menu_Bookmarks->insertAction(before, action);
   }
 
   ui.menu_Bookmarks->insertSeparator(before);
+  g_list_free_full(allBookmarks, (GDestroyNotify)fm_bookmark_item_unref);
 }
 
 void MainWindow::onBookmarksChanged(FmBookmarks* bookmarks, MainWindow* pThis) {
@@ -702,9 +785,22 @@ void MainWindow::onBookmarksChanged(FmBookmarks* bookmarks, MainWindow* pThis) {
 void MainWindow::onBookmarkActionTriggered() {
   BookmarkAction* action = static_cast<BookmarkAction*>(sender());
   FmPath* path = action->path();
-
-  if(path)
-    chdir(path);
+  if(path) {
+    Application* app = static_cast<Application*>(qApp);
+    Settings& settings = app->settings();
+    switch(settings.bookmarkOpenMethod()) {
+    case OpenInCurrentTab: /* current tab */
+    default:
+      chdir(path);
+      break;
+    case OpenInNewTab: /* new tab */
+      addTab(path);
+      break;
+    case OpenInNewWindow: /* new window */
+      (new MainWindow(path))->show();
+      break;
+    }
+  }
 }
 
 void MainWindow::on_actionCopy_triggered() {
@@ -733,7 +829,7 @@ void MainWindow::on_actionDelete_triggered() {
 
   bool shiftPressed = (qApp->keyboardModifiers() & Qt::ShiftModifier ? true : false);
   if(settings.useTrash() && !shiftPressed)
-    FileOperation::trashFiles(paths, settings.confirmDelete(), this);
+    FileOperation::trashFiles(paths, settings.confirmTrash(), this);
   else
     FileOperation::deleteFiles(paths, settings.confirmDelete(), this);
 
@@ -798,6 +894,7 @@ void MainWindow::onBackForwardContextMenu(QPoint pos) {
   QAction* selectedAction = menu.exec(btn->mapToGlobal(pos));
   if(selectedAction) {
     int index = menu.actions().indexOf(selectedAction);
+    ui.filterBar->clear();
     page->jumpToHistory(index);
     updateUIForCurrentPage();
   }
@@ -808,6 +905,7 @@ void MainWindow::updateFromSettings(Settings& settings) {
 
   // menu
   ui.actionDelete->setText(settings.useTrash() ? tr("&Move to Trash") : tr("&Delete"));
+  ui.actionDelete->setIcon(settings.useTrash() ? QIcon::fromTheme("user-trash") : QIcon::fromTheme("edit-delete"));
 
   // side pane
   ui.sidePane->setIconSize(QSize(settings.sidePaneIconSize(), settings.sidePaneIconSize()));
@@ -885,6 +983,25 @@ void MainWindow::on_actionOpenAsRoot_triggered() {
   }
 }
 
+void MainWindow::on_actionFindFiles_triggered() {
+  Application* app = static_cast<Application*>(qApp);
+  FmPathList* selectedPaths = currentPage()->selectedFilePaths();
+  QStringList paths;
+  if(selectedPaths) {
+    for(GList* l = fm_path_list_peek_head_link(selectedPaths); l; l = l->next) {
+      // FIXME: is it ok to use display name here?
+      // This might be broken on filesystems with non-UTF-8 filenames.
+      Fm::Path path(FM_PATH(l->data));
+      paths.append(path.displayName(false));
+    }
+    fm_path_list_unref(selectedPaths);
+  }
+  else {
+    paths.append(currentPage()->pathName());
+  }
+  app->findFiles(paths);
+}
+
 void MainWindow::on_actionOpenTerminal_triggered() {
   TabPage* page = currentPage();
   if(page) {
