@@ -59,6 +59,8 @@ protected Q_SLOTS:
 
   void on_actionNewTab_triggered();
   void on_actionNewWin_triggered();
+  void on_actionNewFolder_triggered();
+  void on_actionNewBlankFile_triggered();
   void on_actionCloseTab_triggered();
   void on_actionCloseWindow_triggered();
   void on_actionFileProperties_triggered();
@@ -96,6 +98,7 @@ protected Q_SLOTS:
   void on_actionDescending_triggered(bool checked);
   void on_actionFolderFirst_triggered(bool checked);
   void on_actionCaseSensitive_triggered(bool checked);
+  void on_actionFilter_triggered(bool checked);
 
   void on_actionApplications_triggered();
   void on_actionComputer_triggered();
@@ -107,6 +110,7 @@ protected Q_SLOTS:
 
   void on_actionOpenTerminal_triggered();
   void on_actionOpenAsRoot_triggered();
+  void on_actionFindFiles_triggered();
 
   void on_actionAbout_triggered();
 
@@ -116,6 +120,8 @@ protected Q_SLOTS:
   void onTabBarCurrentChanged(int index);
   void onTabBarTabMoved(int from, int to);
 
+  void onFilterStringChanged(QString str);
+
   void onShortcutPrevTab();
   void onShortcutNextTab();
   void onShortcutJumpToTab();
@@ -128,6 +134,11 @@ protected Q_SLOTS:
   void onTabPageSortFilterChanged();
 
   void onSidePaneChdirRequested(int type, FmPath* path);
+  void onSidePaneOpenFolderInNewWindowRequested(FmPath* path);
+  void onSidePaneOpenFolderInNewTabRequested(FmPath* path);
+  void onSidePaneOpenFolderInTerminalRequested(FmPath* path);
+  void onSidePaneCreateNewFolderRequested(FmPath* path);
+  void onSidePaneModeChanged(Fm::SidePane::Mode mode);
   void onSplitterMoved(int pos, int index);
 
   void onBackForwardContextMenu(QPoint pos);
