@@ -31,11 +31,42 @@
 #include "application.h"
 #include "cachedfoldermodel.h"
 #include <QTimer>
+#include <QTextStream>
 
 using namespace Fm;
 
 namespace PCManFM {
 
+bool ProxyFilter::filterAcceptsRow(const Fm::ProxyFolderModel* model, FmFileInfo* info) const {
+  if(!model || !info)
+    return true;
+  QString baseName(fm_file_info_get_name(info));
+  if(!virtHiddenList_.isEmpty() && !model->showHidden() && virtHiddenList_.contains(baseName))
+      return false;
+  if(!filterStr_.isEmpty() && !baseName.contains(filterStr_, Qt::CaseInsensitive))
+    return false;
+  return true;
+}
+
+void ProxyFilter::setVirtHidden(FmFolder* folder) {
+  virtHiddenList_ = QStringList(); // reset the list
+  if(!folder) return;
+  if(FmPath* path = fm_folder_get_path(folder)) {
+    char* pathStr = fm_path_to_str(path);
+    if(pathStr) {
+      QString dotHidden = QString(pathStr) + QString("/.hidden");
+      g_free(pathStr);
+      QFile file(dotHidden);
+      if(file.open(QIODevice::ReadOnly | QIODevice::Text)) {
+        QTextStream in(&file);
+        while(!in.atEnd())
+          virtHiddenList_.append(in.readLine());
+        file.close();
+      }
+    }
+  }
+}
+
 TabPage::TabPage(FmPath* path, QWidget* parent):
   QWidget(parent),
   folder_(NULL),
@@ -57,6 +88,11 @@ TabPage::TabPage(FmPath* path, QWidget* parent):
   // newView->setColumnWidth(Fm::FolderModel::ColumnName, 200);
   connect(folderView_, &View::openDirRequested, this, &TabPage::onOpenDirRequested);
   connect(folderView_, &View::selChanged, this, &TabPage::onSelChanged);
+  connect(folderView_, &View::clickedBack, this, &TabPage::backwardRequested);
+  connect(folderView_, &View::clickedForward, this, &TabPage::forwardRequested);
+
+  proxyFilter_ = new ProxyFilter();
+  proxyModel_->addFilter(proxyFilter_);
 
   // FIXME: this is very dirty
   folderView_->setModel(proxyModel_);
@@ -66,8 +102,9 @@ TabPage::TabPage(FmPath* path, QWidget* parent):
 }
 
 TabPage::~TabPage() {
-  qDebug("delete TabPage");
   freeFolder();
+  if(proxyFilter_)
+    delete proxyFilter_;
   if(proxyModel_)
     delete proxyModel_;
   if(folderModel_)
@@ -101,7 +138,6 @@ void TabPage::freeFolder() {
     QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
     pThis->overrideCursor_ = true;
   }
-  qDebug("start-loading");
 #if 0
 #if FM_CHECK_VERSION(1, 0, 2) && 0 // disabled
   if(fm_folder_is_incremental(_folder)) {
@@ -172,9 +208,8 @@ void TabPage::restoreScrollPos() {
     QApplication::restoreOverrideCursor(); // remove busy cursor
     pThis->overrideCursor_ = false;
   }
-  qDebug("finish-loading");
 
-  // After finishing loading the folder, the model is updated, but Qt delays the UI update 
+  // After finishing loading the folder, the model is updated, but Qt delays the UI update
   // for performance reasons. Therefore at this point the UI is not up to date.
   // Of course, the scrollbar ranges are not updated yet. We solve this by installing an Qt timeout handler.
   QTimer::singleShot(10, pThis, SLOT(restoreScrollPos()));
@@ -193,7 +228,7 @@ void TabPage::restoreScrollPos() {
         // Because the two signals are not correctly paired, we need to
         // remove busy cursor here since "finish-loading" is not emitted.
         QApplication::restoreOverrideCursor(); // remove busy cursor
-	pThis->overrideCursor_ = false;
+        pThis->overrideCursor_ = false;
         return FM_JOB_RETRY;
       }
     }
@@ -317,6 +352,11 @@ void TabPage::chdir(FmPath* newPath, bool addHistory) {
   g_free(disp_name);
 
   folder_ = fm_folder_from_path(newPath);
+  proxyFilter_->setVirtHidden(folder_);
+  if(addHistory) {
+    // add current path to browse history
+    history_.add(path());
+  }
   g_signal_connect(folder_, "start-loading", G_CALLBACK(onFolderStartLoading), this);
   g_signal_connect(folder_, "finish-loading", G_CALLBACK(onFolderFinishLoading), this);
   g_signal_connect(folder_, "error", G_CALLBACK(onFolderError), this);
@@ -328,7 +368,10 @@ void TabPage::chdir(FmPath* newPath, bool addHistory) {
 
   folderModel_ = CachedFolderModel::modelFromFolder(folder_);
   proxyModel_->setSourceModel(folderModel_);
-  proxyModel_->sort(Fm::FolderModel::ColumnFileName);
+  proxyModel_->sort(proxyModel_->sortColumn(), proxyModel_->sortOrder());
+  Settings& settings = static_cast<Application*>(qApp)->settings();
+  proxyModel_->setFolderFirst(settings.sortFolderFirst());
+  proxyModel_->sort(settings.sortColumn(), settings.sortOrder());
 
   if(fm_folder_is_loaded(folder_)) {
     onFolderStartLoading(folder_, this);
@@ -337,12 +380,6 @@ void TabPage::chdir(FmPath* newPath, bool addHistory) {
   }
   else
     onFolderStartLoading(folder_, this);
-
-  if(addHistory) {
-    // add current path to browse history
-    QAbstractItemView* childView = folderView_->childView();
-    history_.add(path());
-  }
 }
 
 void TabPage::selectAll() {
@@ -381,15 +418,13 @@ void TabPage::onSelChanged(int numSel) {
       fm_file_info_list_unref(files);
     }
     else {
-      FmFileInfoList* files;
       goffset sum;
       GList* l;
-      char size_str[128];
       msg = tr("%1 item(s) selected", NULL, numSel).arg(numSel);
       /* don't count if too many files are selected, that isn't lightweight */
       if(numSel < 1000) {
         sum = 0;
-        files = folderView_->selectedFiles();
+        FmFileInfoList* files = folderView_->selectedFiles();
         for(l = fm_file_info_list_peek_head_link(files); l; l = l->next) {
           if(fm_file_info_is_dir(FM_FILE_INFO(l->data))) {
             /* if we got a directory then we cannot tell it's size
@@ -400,6 +435,7 @@ void TabPage::onSelChanged(int numSel) {
           sum += fm_file_info_get_size(FM_FILE_INFO(l->data));
         }
         if(sum >= 0) {
+          char size_str[128];
           fm_file_size_to_str(size_str, sizeof(size_str), sum,
                               fm_config->si_unit);
 	  msg += QString(" (%1)").arg(QString::fromUtf8(size_str));
@@ -470,4 +506,19 @@ void TabPage::updateFromSettings(Settings& settings) {
   folderView_->updateFromSettings(settings);
 }
 
+void TabPage::setShowHidden(bool showHidden) {
+  if(!proxyModel_ || showHidden == proxyModel_->showHidden())
+    return;
+  proxyModel_->setShowHidden(showHidden);
+  statusText_[StatusTextNormal] = formatStatusText();
+  Q_EMIT statusChanged(StatusTextNormal, statusText_[StatusTextNormal]);
+}
+
+void TabPage:: applyFilter() {
+  if(!proxyModel_) return;
+  proxyModel_->updateFilters();
+  statusText_[StatusTextNormal] = formatStatusText();
+  Q_EMIT statusChanged(StatusTextNormal, statusText_[StatusTextNormal]);
+}
+
 };
